<?php

declare(strict_types=1);

namespace Dedi\SyliusTaxonTypePlugin\Repository;

use Dedi\SyliusTaxonTypePlugin\Model\TypedTaxonInterface;
use Doctrine\ORM\QueryBuilder;
use Sylius\Bundle\TaxonomyBundle\Doctrine\ORM\TaxonRepository as BaseTaxonRepository;

class TaxonRepository extends BaseTaxonRepository
{
    public function findAllBrands(): QueryBuilder
    {
        return $this->createQueryBuilder('t')
            ->where('t.type = :brand')
            ->setParameter('brand', TypedTaxonInterface::BRAND_TYPE)
        ;
    }

    /**
     * @inheritdoc
     */
    public function findBrandByPhrase(string $locale, string $phrase): array
    {
        return $this->createQueryBuilder('t')
            ->innerJoin('t.translations', 'translation', 'WITH', 'translation.locale = :locale')
            ->where('t.type = :brand')
            ->andWhere('translation.name LIKE :phrase OR t.code LIKE :phrase')
            ->setParameter('brand', TypedTaxonInterface::BRAND_TYPE)
            ->setParameter('phrase', '%' . $phrase . '%')
            ->setParameter('locale', $locale)
            ->getQuery()
            ->getResult()
        ;
    }
}
